@@ -73,27 +73,30 @@ def get_body(loc: Path) -> str:
     return f.read()
 
 
-def get_legacy_file(loc: Path) -> Path:
+def get_legacy_file(loc: Path, context: str) -> Path:
     text = str(loc)
     parts = text.split("/")
     num = parts[-1]
-    filename = f"ra{num}.yaml"
+    filename = f"{context}{num}.yaml"
     return loc / filename
 
 
 def get_details(loc: Path) -> Optional[dict]:
     try:
-        with open(loc / "details.yaml", "r") as r:
-            return yaml.load(r, Loader=yaml.FullLoader)
+        details = loc / "details.yaml"
+        if not details.exists():
+            return None
+        with open(details, "r") as r:
+            return yaml.load(r, Loader=yaml.FullLoader) | set_whereas(loc)
+
     except FileNotFoundError:
         return None
 
 
 def add_old(filename: Path, data: dict) -> dict:
     with open(filename, "r") as r:
-        unit_data = yaml.load(r, Loader=yaml.FullLoader)
-        data |= unit_data
-        data.pop("order")
+        result = yaml.load(r, Loader=yaml.FullLoader)
+        data["units"] = result["units"]
         return data
 
 
@@ -122,7 +125,7 @@ def set_whereas(loc: Path) -> dict:
     return {"whereas_clause": None}
 
 
-def load_data(loc: Path) -> Optional[dict]:
+def load_statute(loc: Path) -> Optional[dict]:
     """With the passed directory, get the relevant files.
 
     The high-level configuration file for the law is `details.yaml`
@@ -161,9 +164,7 @@ def load_data(loc: Path) -> Optional[dict]:
         print(f"No details.yaml file: {loc}.")
         return None
 
-    data |= set_whereas(loc)
-
-    legacy_file = get_legacy_file(loc)
+    legacy_file = get_legacy_file(loc, data["category"])
     if legacy_file.exists():
         return add_old(legacy_file, data)
     else:
@@ -179,13 +180,13 @@ def get_directory(
 
     Args:
         location (Path): Where the source material is stored
-        law_category (str): Must be either "ra", "eo", "pd", "ca", "bp", "act"
+        law_category (str): Must be either "ra", "eo", "pd", "ca", "bp", "act", "const"
         serial_num (str): A digit-like identifier, e.g. 209, 158-a, etc.
 
     Returns:
         Path: [description]
     """
-    if law_category not in ["ra", "eo", "pd", "ca", "bp", "act"]:
+    if law_category not in ["ra", "eo", "pd", "ca", "bp", "act", "const"]:
         return None
 
     directory = location / f"{law_category}" / f"{serial_num}"
@@ -208,6 +209,9 @@ def get_title(category: str, num: str):
         category_text = "Commonwealth Act No."
     elif category == "act":
         category_text = "Act No."
+    elif category == "const":
+        category_text = num
+        num = "Constitution"
     return f"{category_text} {num}"
 
 
@@ -233,7 +237,7 @@ def preprocess(
     if not folder:
         return None
 
-    source = load_data(folder)
+    source = load_statute(folder)
     if not source:
         return None
 
@@ -279,38 +283,3 @@ def get_statute(parent: Path, child: Path, context: str) -> Optional[dict]:
     else:
         print(f"Missing data: {child}")
         return None
-
-
-def decode_statutes(parent: Path, context: str):
-    """Given a parent directory "location" with a subfolder named "context",
-    generate decision-like data from entries of the subfolder, or the grandchildren of the parent directory.
-
-    Args:
-        context (str): "ra" is the folder name
-
-    Returns:
-        [type]: [description]
-
-    Yields:
-        Iterator[dict]: Dictionaries containing data in dictionary format
-    """
-    folder = parent / "statutes"
-    subfolder = folder / context
-    for child in subfolder.glob("*"):
-        yield get_statute(folder, child, context)
-
-
-def dump_statute_data(target_directory: Path, data: dict):
-    with open(target_directory, "w") as writefile:
-        yaml.dump(data=data, stream=writefile, sort_keys=False)
-        if target_directory / "data.yaml":
-            print(f"Added data to: {target_directory}")
-
-
-def create_statute_data(source_loc: Path, context: str):
-    statutes_data = decode_statutes(source_loc, context)
-    for data in statutes_data:
-        if not source_loc / context / "data.yaml":
-            dump_statute_data(source_loc / context, data)
-        else:
-            print(f"Existing data file: {source_loc / context}")
